// samplepackage/src/ChartComponent.tsx

import React, { useEffect, useState } from 'react';
import defaultApis from './defaultApis';
interface ChartComponentProps {
  api: keyof typeof defaultApis;
}

const ChartComponent: React.FC<ChartComponentProps> = ({ api }) => {
  const [data, setData] = useState<any[]>([]);

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await fetch(defaultApis[api]);
        if (!response.ok) {
          throw new Error('Network response was not ok');
        }
        const data = await response.json();
        setData(data);
      } catch (error) {
        console.error('Error fetching data:', error);
      }
    };

    fetchData();
  }, [api]);

  return (
    <div>
      <h2>Data from {api}</h2>
      <pre>{JSON.stringify(data, null, 2)}</pre>
    </div>
  );
};

export default ChartComponent;
