// samplechartfetch/src/ContentPage.tsx

import React, { useEffect, useState } from 'react';
import defaultApis from '../../defaultApis'; // Import the defaultApis object

interface ContentPageProps {
  api: keyof typeof defaultApis; // Use keyof to enforce the API key to be one of the keys in defaultApis
}

const ContentPage: React.FC<ContentPageProps> = ({ api }) => {
  const [data, setData] = useState<any[]>([]);

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await fetch(defaultApis[api]);
        if (!response.ok) {
          throw new Error('Network response was not ok');
        }
        const data = await response.json();
        setData(data);
      } catch (error) {
        console.error('Error fetching data:', error);
      }
    };

    fetchData();
  }, [api]);

  return (
    <div>
      <h1>{api} Data</h1>
      <pre>{JSON.stringify(data, null, 2)}</pre>
    </div>
  );
};

export default ContentPage;
